@@ -134,9 +134,7 @@ Segmentation::load_prefix (const char *prefix_dir)
     for (int i = 0; i < dl.num_entries; i++) {
         /* Look at filename, make sure it is an mha or nrrd file */
         const char *entry = dl.entries[i];
-	if (!extension_is (entry, ".mha") 
-            && !extension_is (entry, ".nrrd"))
-        {
+        if (!Segmentation::valid_extension (entry)) {
             continue;
         }
         max_structures++;
@@ -152,12 +150,7 @@ Segmentation::load_prefix (const char *prefix_dir)
     for (int i = 0; i < dl.num_entries; i++) {
         /* Look at filename, make sure it is an mha or nrrd file */
         const char *entry = dl.entries[i];
-	if (!extension_is (entry, ".mha") 
-            && !extension_is (entry, ".mhd")
-            && !extension_is (entry, ".nii")
-            && !extension_is (entry, ".nii.gz")
-            && !extension_is (entry, ".nrrd"))
-        {
+        if (!Segmentation::valid_extension (entry)) {
             continue;
         }
 
@@ -345,6 +338,16 @@ Segmentation::load_xio (const Xio_studyset& studyset)
     d_ptr->m_ss_img_valid = false;
 }
 
+bool
+Segmentation::valid_extension (const char *filename)
+{
+    return extension_is (filename, ".mha") 
+        || extension_is (filename, ".mhd")
+        || extension_is (filename, ".nii")
+        || extension_is (filename, ".nii.gz")
+        || extension_is (filename, ".nrrd");
+}
+
 size_t
 Segmentation::get_num_structures ()
 {
@@ -716,7 +719,7 @@ Segmentation::convert_ss_img_to_cxt (void)
         /* Image type must be uint32_t */
         d_ptr->m_ss_img->convert (PLM_IMG_TYPE_ITK_ULONG);
 
-        /* Do extraction */
+        /* Do extraction -- this branch is used by plastimatch synth */
         lprintf ("Doing extraction\n");
         ::cxt_extract (d_ptr->m_rtss.get(), d_ptr->m_ss_img->m_itk_uint32, -1, 
             use_existing_bits);
@@ -973,8 +976,9 @@ Segmentation::set_structure_image (
 
     /* Expand vector length if needed */
     UCharVecImageType::Pointer ss_img = d_ptr->m_ss_img->itk_uchar_vec ();
-    if (uchar_no > ss_img->GetVectorLength()) {
-        this->broaden_ss_image (uchar_no);
+    if ((uchar_no+1) > ss_img->GetVectorLength()) {
+        lprintf ("Broadening ss_image\n");
+        this->broaden_ss_image (uchar_no+1);
     }
 
     /* Set up iterators for looping through images */
