@@ -4,19 +4,13 @@
 #ifndef _itk_log_demons_h_
 #define _itk_log_demons_h_
 
-#include "itkLogDomainDemonsRegistrationFilterWithMaskExtension.h"
-#include <itk_demons_registration_filter.h>
+#include "plmregister_config.h"
+#include "itk_demons_types.h"
+#include "itk_demons_registration_filter.h"
 
 class itk_log_domain_demons_filter: public itk_demons_registration_filter
 {
-
-    typedef itk::LogDomainDemonsRegistrationFilterWithMaskExtension<
-        FloatImageType,
-        FloatImageType,
-        DeformationFieldType> LogDomainDemonsFilterType;
-
     typedef LogDomainDemonsFilterType::DemonsRegistrationFunctionType LogDomainDemonsFunctionType;
-
     typedef LogDomainDemonsFunctionType::GradientType GradientType;
 
 public:
