@@ -6,12 +6,13 @@
 
 enum Similarity_metric_type {
     SIMILARITY_METRIC_NONE,
-    SIMILARITY_METRIC_DMAP,
+    SIMILARITY_METRIC_DMAP_DMAP,
     SIMILARITY_METRIC_GM,
     SIMILARITY_METRIC_MI_MATTES,
     SIMILARITY_METRIC_MI_VW,
     SIMILARITY_METRIC_MSE,
-    SIMILARITY_METRIC_NMI
+    SIMILARITY_METRIC_NMI,
+    SIMILARITY_METRIC_POINT_DMAP
 };
 
 const char* similarity_metric_type_string (Similarity_metric_type);
