@@ -175,7 +175,7 @@ warp_and_save_ss (
         || parms->xf_in_fn != ""
         || parms->output_prefix != "")
     {
-
+        lprintf ("Warp_and_save_ss: seg->rasterize\n");
         /* In the following cases, we should use the default 
            rasterization geometry (i.e. cxt->rast_xxx):
            (a) Warping
@@ -187,18 +187,20 @@ warp_and_save_ss (
            In the other cases we can directly rasterize to the output 
            geometry.
         */
-        Plm_image_header pih;
         Rtss *cxt = seg->get_structure_set_raw ();
         if (parms->xf_in_fn != "") {
+            Plm_image_header pih;
             pih.set_from_gpuit (cxt->rast_dim, cxt->rast_offset, 
                 cxt->rast_spacing, 0);
+            seg->rasterize (&pih,
+                parms->output_labelmap_fn != "",
+                parms->xor_contours);
         } else {
-            pih.set_from_gpuit (cxt->m_dim, cxt->m_offset, cxt->m_spacing, 0);
+            /* Use pih passed as argument */
+            seg->rasterize (pih,
+                parms->output_labelmap_fn != "",
+                parms->xor_contours);
         }
-        lprintf ("Warp_and_save_ss: seg->rasterize\n");
-        seg->rasterize (&pih,
-            parms->output_labelmap_fn != "",
-            parms->xor_contours);
     }
 
     /* Do the warp */
@@ -359,11 +361,24 @@ rt_study_warp (Rt_study *rt_study, Plm_file_format file_type, Warp_parms *parms)
        If it doesn't we need to resample to get the output geometry. 
        We need to supply an identity xform if none was supplied, 
        so that the warp function can do the resample. */
-    bool pih_changed = false;
+    bool image_pih_changed = false;
     if (rt_study->get_image()) {
         Plm_image_header pih_input_image (rt_study->get_image());
         if (!Plm_image_header::compare (&pih_input_image, &pih)) {
-            pih_changed = true;
+            image_pih_changed = true;
+            if (parms->xf_in_fn == "") {
+                TranslationTransformType::Pointer trn
+                    = TranslationTransformType::New();
+                xform->set_trn(trn);
+            }
+        }
+    }
+    /* If the user wants to resize the dose, do this as well */
+    bool dose_pih_changed = false;
+    if (parms->resize_dose && rt_study->have_dose()) {
+        Plm_image_header pih_input_dose (rt_study->get_dose());
+        if (!Plm_image_header::compare (&pih_input_dose, &pih)) {
+            dose_pih_changed = true;
             if (parms->xf_in_fn == "") {
                 TranslationTransformType::Pointer trn
                     = TranslationTransformType::New();
@@ -375,7 +390,7 @@ rt_study_warp (Rt_study *rt_study, Plm_file_format file_type, Warp_parms *parms)
     /* Warp the image and create vf */
     if (rt_study->have_image()
         && (parms->xf_in_fn != ""
-            || pih_changed)
+            || image_pih_changed)
         && (parms->output_img_fn != ""
             || parms->output_vf_fn != ""
             || parms->output_dicom != ""))
@@ -399,7 +414,7 @@ rt_study_warp (Rt_study *rt_study, Plm_file_format file_type, Warp_parms *parms)
 
     /* Warp the dose image */
     if (rt_study->has_dose()
-        && parms->xf_in_fn != ""
+        && (parms->xf_in_fn != "" || dose_pih_changed)
         && (parms->output_dose_img_fn != ""
             || parms->output_xio_dirname != ""
             || parms->output_dicom != ""))
